import java.net.*;
import java.io.*;

/**
 * CommunicationChannel.java<br>
 *Die Klasse verwaltet die Kommunikation zwischen Client und Server<br>
 *
 * @author <a href="mailto:unbequemecouch@web.de">Matthias Bernges</a>
 * @version 0.5
 */

public class CommunicationChannel {
    private InetAddress IP;
    private int port;
    private DatagramSocket socket;

    /**
     *Generiert einen <code>CommunicationChannel</code>
     *
     *@param ip die Adresse des Servers
     *@param port der Port des Servers
     */ 
    public CommunicationChannel (InetAddress ip, int port){
	this.IP=ip;
	this.port=port;
	try {
	    this.socket=new DatagramSocket();
	}catch (SocketException e) {
	    System.err.println("datagram socket kann nicht angelegt werden\n");
	    System.exit(1);
	}
    }

    /**
     *Generiert einen <code>CommunicationChannel</code>
     *
     *@param host Die Adresse des Servers
     *@param port Der Port des Servers
     */
    public CommunicationChannel(String host, int port) {
	try {
	    this.IP=InetAddress.getByName(host);
	} catch (UnknownHostException e) {
	    System.err.println("Hostname kann nicht aufgelst werden\n");
	    System.exit(1);
	}
	this.port=port;
	try {
	    this.socket=new DatagramSocket();
	}catch (SocketException e) {
	    System.err.println("datagram socket kann nicht angelegt werden\n");
	    System.exit(1);
	}
    }

    /**
     *Generiert einen <code>CommunicationChannel</code> der den localhost anspricht
     *
     *@param port der Port des Servers
     */
    public CommunicationChannel(int port){
	try {
	    this.IP=InetAddress.getLocalHost();
	} catch (UnknownHostException e) {
	    System.err.println("Hostname kann nicht aufgelst werden\n");
	    System.exit(1);
	}
	this.port=port;
	try {
	    this.socket=new DatagramSocket();
	}catch (SocketException e) {
	    System.err.println("datagram socket kann nicht angelegt werden\n");
	    System.exit(1);
	}
    }

    /**
     *Gibt die Adresse des Servers zurck
     *@return Die Adresse des Servers
     */
    public InetAddress getIP(){
	return this.IP;
    }

    /**
     *Gibt den Port des Servers zurck
     *@return Den Serverport
     */
    public int getPort(){
	return this.port;
    }

    /**
     *Sendet ein Nachrichtenpacket an den Server
     *
     *@param message Die Nachricht die an den Server gesendet wird
     */
    public void send(String message){
	try{
	    byte[] b = message.getBytes();
	    DatagramPacket dp =	new DatagramPacket(b, b.length, IP, port);
            socket.send(dp);
        } catch (IOException e) {
            System.err.println("Paket konnte nicht gesendet werden\n");
        }
    }
    /**
     *Empfngt ein Paket vom Server
     *
     *@return Die empfangene Nachricht als String
     */
    public String receive(){
        byte[] b = new byte[1024];
	String s;
        DatagramPacket dp = new DatagramPacket(b, b.length);
        try {
            socket.receive(dp);
        } catch (IOException e) {
            System.err.println("Packet konnte nicht empfangen werden\n.");
        }
        port = dp.getPort();
	s=new String(dp.getData());
	s=s.substring(0,dp.getLength()-1);
        return s;
    }
    
}// CommunicationChannel
